#
# See the file "LICENSE" for the full license governing this code.
#
# frozen_string_literal: true

require 'entitlement/entry'
require 'facter'

module Entitlement
  # Docs
  class DomainsEntry < Entry
    def initialize(modules, from, to, filename_string, domains, &proc)
      super(modules, from, to, filename_string, &proc)
      @domains = Array[domains].flatten
    end

    def valid?(module_name, resources = nil)
      Puppet.debug 'Found a domain entitlement....'
      super ? valid_domain?(current_domain) : false
    end

    def inspect
      super
      puts "For domains : #{@domains.join(',')}"
    end

    def valid_domain?(domain)
      @domains.any? do |entitled_domain|
        if entitled_domain.is_a?(String)
          domain == entitled_domain
        else
          domain.scan(entitled_domain).any?
        end
      end
    end

    private

    def current_domain
      Facter.value('domain')
    end
  end
end
