#
# See the file "LICENSE" for the full license governing this code.
#
# frozen_string_literal: true

require 'entitlement/entry'
require 'facter'

module Entitlement
  # Docs
  class NodesEntry < Entry
    def initialize(modules, from, to, filename_string, nodes, &proc)
      super(modules, from, to, filename_string, &proc)
      @nodes = Array[nodes].flatten
    end

    def valid?(module_name, resources = nil)
      Puppet.debug 'Found a node entitlement....'
      super ? valid_node?(current_node) : false
    end

    def inspect
      super
      puts "For nodes   : #{@nodes.join(',')}"
    end

    private

    def valid_node?(node)
      @nodes.any? do |entitled_node|
        if entitled_node.is_a?(String)
          node.casecmp(entitled_node) == 0
        else
          node.scan(entitled_node).any?
        end
      end
    end

    def current_node
      Facter.value('fqdn')
    end
  end
end
