#
# See the file "LICENSE" for the full license governing this code.
#
# frozen_string_literal: true

require 'puppet/face'
require 'fileutils'
require 'entitlement/entitlement'

Puppet::Face.define(:emlicense, '0.0.1') do
  action(:purge) do
    summary 'Purge all expired EM licenses'

    description <<-DESCR
      Purge all expired EM licenses
    DESCR

    option '--force', '-f' do
      summary "Force the removal of old entitlements. Don't ask."
      default_to { false }
      description <<-DESC
        Force the removal of old entitlements. Don't ask
      DESC
    end

    option '--list', '-l' do
      summary 'Only list all purgable entitlements.'
      default_to { false }
      description <<-DESC
        Only list all purgable entitlements.
      DESC
    end

    when_invoked do |*args|
      options = args.pop
      if options[:list]
        purgable_files = ::Entitlement::Entitlement.purgeable
        if purgable_files.any?
          puts 'Following files can be removed because they contain expired entitlements:'
          purgable_files.each { |f| puts f }
        else
          puts 'No entitlement files with expired entitlements found.'
        end
        return
      end
      ::Entitlement::Entitlement.purgeable.each do |file|
        if options[:force]
          Puppet.notice "Purged file #{file}. because it contains no valid entitlements..."
          FileUtils.rm(file)
        else
          print "File #{file} contains no valid entitlements anymore. Delete it?(Y/N) [N]: "
          answer = $stdin.readline
          answer = 'N' if answer == "\n"
          FileUtils.rm(file) if answer =~ /Y(es)?/i
        end
      end
      nil
    end
  end
end
