# frozen_string_literal: true

#
# @summary This function uses its current scope te infer what control is called and then checks to see
#          if the validator is already in the catalog. If it isn't, we add it.
#
#
Puppet::Functions.create_function('easy_type::delegate_to_validator', Puppet::Functions::InternalFunction) do
  dispatch :delegate_to_validator do
    scope_param
  end

  def delegate_to_validator(scope)
    validator_ref  = scope.to_s.gsub('::Controls::','::Validators::').gsub(/^Scope\(|\)$/,'')
    validator_impl = scope.catalog.resources.select  { |e| e.to_s == validator_ref }.first
    validator_type = validator_ref.downcase.gsub(/\[.*\]/, '')
    name           = validator_ref.scan(/\[(.*)\]/).flatten.first
    #
    # If already in catalog do nothing
    #
    if validator_impl.nil? 
      create_resources(validator_type, { name => {}})
    else
      scope.debug "Validator already in catalog so skipping."
    end
  end

  def create_resources(type, resources)
    call_function('create_resources', type, resources)
  end
end
